pub struct VarDeclaration(pub VariableList);Expand description
A var statement, also called VariableStatement in the spec.
The scope of a variable declared with var is its current execution context, which is either
the enclosing function or, for variables declared outside any function, global. If you
re-declare a ECMAScript variable, it will not lose its value.
Although a bit confusing, VarDeclarations are not considered Declarations by the spec.
This is partly because it has very different semantics from let and const declarations, but
also because a var statement can be labelled just like any other Statement:
label: var a = 5;
a;returns 5 as the value of the statement list, while:
label: let a = 5;
a;throws a SyntaxError.
var declarations, wherever they occur, are processed before any code is executed. This is
called hoisting.
Tuple Fields
0: VariableListTrait Implementations
Sourceimpl Clone for VarDeclaration
impl Clone for VarDeclaration
Sourcefn clone(&self) -> VarDeclaration
fn clone(&self) -> VarDeclaration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VarDeclaration
impl Debug for VarDeclaration
Sourceimpl<'de> Deserialize<'de> for VarDeclaration
impl<'de> Deserialize<'de> for VarDeclaration
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<VarDeclaration, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<VarDeclaration, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a> From<&'a VarDeclaration> for NodeRef<'a>
impl<'a> From<&'a VarDeclaration> for NodeRef<'a>
Sourcefn from(node: &'a VarDeclaration) -> NodeRef<'a>
fn from(node: &'a VarDeclaration) -> NodeRef<'a>
Converts to this type from the input type.
Sourceimpl<'a> From<&'a mut VarDeclaration> for NodeRefMut<'a>
impl<'a> From<&'a mut VarDeclaration> for NodeRefMut<'a>
Sourcefn from(node: &'a mut VarDeclaration) -> NodeRefMut<'a>
fn from(node: &'a mut VarDeclaration) -> NodeRefMut<'a>
Converts to this type from the input type.
Sourceimpl From<VarDeclaration> for ForLoopInitializer
impl From<VarDeclaration> for ForLoopInitializer
Sourcefn from(list: VarDeclaration) -> ForLoopInitializer
fn from(list: VarDeclaration) -> ForLoopInitializer
Converts to this type from the input type.
Sourceimpl From<VarDeclaration> for Statement
impl From<VarDeclaration> for Statement
Sourcefn from(var: VarDeclaration) -> Statement
fn from(var: VarDeclaration) -> Statement
Converts to this type from the input type.
Sourceimpl PartialEq for VarDeclaration
impl PartialEq for VarDeclaration
Sourceimpl Serialize for VarDeclaration
impl Serialize for VarDeclaration
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl ToInternedString for VarDeclaration
impl ToInternedString for VarDeclaration
Sourcefn to_interned_string(&self, interner: &Interner) -> String
fn to_interned_string(&self, interner: &Interner) -> String
Converts a given element to a string using an interner.
Sourceimpl VisitWith for VarDeclaration
impl VisitWith for VarDeclaration
Sourcefn visit_with<'a, V>(
&'a self,
visitor: &mut V,
) -> ControlFlow<<V as Visitor<'a>>::BreakTy>where
V: Visitor<'a>,
fn visit_with<'a, V>(
&'a self,
visitor: &mut V,
) -> ControlFlow<<V as Visitor<'a>>::BreakTy>where
V: Visitor<'a>,
Visit this node with the provided visitor.
Sourcefn visit_with_mut<'a, V>(
&'a mut self,
visitor: &mut V,
) -> ControlFlow<<V as VisitorMut<'a>>::BreakTy>where
V: VisitorMut<'a>,
fn visit_with_mut<'a, V>(
&'a mut self,
visitor: &mut V,
) -> ControlFlow<<V as VisitorMut<'a>>::BreakTy>where
V: VisitorMut<'a>,
Visit this node with the provided visitor mutably, allowing the visitor to modify private
fields.
impl StructuralPartialEq for VarDeclaration