pub struct Variable { /* private fields */ }Expand description
Variable represents a variable declaration of some kind.
For let and const declarations this type represents a LexicalBinding
For var declarations this type represents a VariableDeclaration
More information:
Implementations
Sourceimpl Variable
impl Variable
Sourcepub const fn from_identifier(
ident: Identifier,
init: Option<Expression>,
) -> Variable
pub const fn from_identifier( ident: Identifier, init: Option<Expression>, ) -> Variable
Creates a new variable declaration from a BindingIdentifier.
Sourcepub const fn from_pattern(
pattern: Pattern,
init: Option<Expression>,
) -> Variable
pub const fn from_pattern( pattern: Pattern, init: Option<Expression>, ) -> Variable
Creates a new variable declaration from a Pattern.
Sourcepub const fn init(&self) -> Option<&Expression>
pub const fn init(&self) -> Option<&Expression>
Gets the initialization expression for the variable declaration, if any.