Expression

Enum Expression 

pub enum Expression {
Show 33 variants This(This), Identifier(Identifier), Literal(Literal), RegExpLiteral(RegExpLiteral), ArrayLiteral(ArrayLiteral), ObjectLiteral(ObjectLiteral), Spread(Spread), FunctionExpression(FunctionExpression), ArrowFunction(ArrowFunction), AsyncArrowFunction(AsyncArrowFunction), GeneratorExpression(GeneratorExpression), AsyncFunctionExpression(AsyncFunctionExpression), AsyncGeneratorExpression(AsyncGeneratorExpression), ClassExpression(Box<ClassExpression>), TemplateLiteral(TemplateLiteral), PropertyAccess(PropertyAccess), New(New), Call(Call), SuperCall(SuperCall), ImportCall(ImportCall), Optional(Optional), TaggedTemplate(TaggedTemplate), NewTarget(NewTarget), ImportMeta(ImportMeta), Assign(Assign), Unary(Unary), Update(Update), Binary(Binary), BinaryInPrivate(BinaryInPrivate), Conditional(Conditional), Await(Await), Yield(Yield), Parenthesized(Parenthesized), // some variants omitted
}
The Expression Parse Node.

See the module level documentation for more information.

Variants



This(This)

The ECMAScript this keyword refers to the object it belongs to.

A property of an execution context (global, function or eval) that, in non–strict mode, is always a reference to an object and in strict mode can be any value.

More information:



Identifier(Identifier)



Literal(Literal)

See Literal.



RegExpLiteral(RegExpLiteral)



ArrayLiteral(ArrayLiteral)



ObjectLiteral(ObjectLiteral)



Spread(Spread)

See Spread,



FunctionExpression(FunctionExpression)



ArrowFunction(ArrowFunction)



AsyncArrowFunction(AsyncArrowFunction)



GeneratorExpression(GeneratorExpression)



AsyncFunctionExpression(AsyncFunctionExpression)



AsyncGeneratorExpression(AsyncGeneratorExpression)



ClassExpression(Box<ClassExpression>)



TemplateLiteral(TemplateLiteral)



PropertyAccess(PropertyAccess)



New(New)

See New.



Call(Call)

See Call.



SuperCall(SuperCall)

See SuperCall.



ImportCall(ImportCall)



Optional(Optional)

See Optional.



TaggedTemplate(TaggedTemplate)



NewTarget(NewTarget)

The new.target pseudo-property expression.



ImportMeta(ImportMeta)

The import.meta pseudo-property expression.



Assign(Assign)

See Assign.



Unary(Unary)

See Unary.



Update(Update)

See Unary.



Binary(Binary)

See Binary.



BinaryInPrivate(BinaryInPrivate)



Conditional(Conditional)



Await(Await)

See Await.



Yield(Yield)

See Yield.



Parenthesized(Parenthesized)

Implementations

Source

impl Expression

pub const fn is_anonymous_function_definition(&self) -> bool

Returns if the expression is a function definition without a name.

More information:

pub fn set_anonymous_function_definition_name(&mut self, name: &Identifier)

Sets the name of an anonymous function definition.

This is used to set the name of a function expression when it is assigned to a variable. If the function already has a name, this does nothing.

pub const fn flatten(&self) -> &Expression

Returns the expression without any outer parenthesized expressions.