pub struct Assign { /* private fields */ }Expand description
An assignment operator expression.
See the module level documentation for more information.
Implementations
Sourceimpl Assign
impl Assign
Sourcepub fn new(op: AssignOp, lhs: AssignTarget, rhs: Expression) -> Assign
pub fn new(op: AssignOp, lhs: AssignTarget, rhs: Expression) -> Assign
Creates an Assign AST Expression.
Sourcepub const fn lhs(&self) -> &AssignTarget
pub const fn lhs(&self) -> &AssignTarget
Gets the left hand side of the assignment operation.
Sourcepub const fn rhs(&self) -> &Expression
pub const fn rhs(&self) -> &Expression
Gets the right hand side of the assignment operation.