pub enum UpdateOp {
IncrementPost,
IncrementPre,
DecrementPost,
DecrementPre,
}Expand description
A update operator is one that takes a single operand/argument and performs an operation.
More information:
Variants
IncrementPost
The increment operator increments (adds one to) its operand and returns a value.
Syntax: x++
This operator increments and returns the value after incrementing.
More information:
IncrementPre
The increment operator increments (adds one to) its operand and returns a value.
Syntax: ++x
This operator increments and returns the value before incrementing.
More information:
DecrementPost
The decrement operator decrements (subtracts one from) its operand and returns a value.
Syntax: x--
This operator decrements and returns the value before decrementing.
More information:
DecrementPre
The decrement operator decrements (subtracts one from) its operand and returns a value.
Syntax: --x
This operator decrements the operand and returns the value after decrementing.
More information: