pub struct Await { /* private fields */ }Expand description
An await expression is used within an async function to pause execution and wait for a promise to resolve.
More information:
Implementations