pub struct Identifier { /* private fields */ }Expand description
An identifier is a sequence of characters in the code that identifies a variable,
function, or property.
In ECMAScript, identifiers are case-sensitive and can contain Unicode letters, $, _, and digits (0-9), but may not start with a digit.
An identifier differs from a string in that a string is data, while an identifier is part of the code. In JavaScript, there is no way to convert identifiers to strings, but sometimes it is possible to parse strings into identifiers.
More information:
Implementations
Sourceimpl Identifier
impl Identifier
Sourcepub const fn new(ident: Sym, span: Span) -> Identifier
pub const fn new(ident: Sym, span: Span) -> Identifier
Creates a new identifier AST Expression.