pub struct Optional { /* private fields */ }Expand description
An optional chain expression, as defined by the spec.
Optional chaining allows for short-circuiting property accesses and function calls, which
will return undefined instead of returning an error if the access target or the call is
either undefined or null.
An example of optional chaining:
const adventurer = {
name: 'Alice',
cat: {
name: 'Dinah'
}
};
console.log(adventurer.cat?.name); // Dinah
console.log(adventurer.dog?.name); // undefinedImplementations
Sourceimpl Optional
impl Optional
Sourcepub fn new(
target: Expression,
chain: Box<[OptionalOperation]>,
span: Span,
) -> Optional
pub fn new( target: Expression, chain: Box<[OptionalOperation]>, span: Span, ) -> Optional
Creates a new Optional expression.
Sourcepub fn target(&self) -> &Expression
pub fn target(&self) -> &Expression
Gets the target of this Optional expression.
Sourcepub fn chain(&self) -> &[OptionalOperation]
pub fn chain(&self) -> &[OptionalOperation]
Gets the chain of accesses and calls that will be applied to the target at runtime.