pub struct OptionalOperation { /* private fields */ }Expand description
Operation within an Optional chain.
An operation within an Optional chain can be either shorted or non-shorted. A shorted operation
(?.item) will force the expression to return undefined if the target is undefined or null.
In contrast, a non-shorted operation (.prop) will try to access the property, even if the target
is undefined or null.
Implementations
Sourceimpl OptionalOperation
impl OptionalOperation
Sourcepub const fn new(
kind: OptionalOperationKind,
shorted: bool,
span: Span,
) -> OptionalOperation
pub const fn new( kind: OptionalOperationKind, shorted: bool, span: Span, ) -> OptionalOperation
Creates a new OptionalOperation.
Sourcepub const fn kind(&self) -> &OptionalOperationKind
pub const fn kind(&self) -> &OptionalOperationKind
Gets the kind of operation.