Module function

Module function 

This module contains Function and Class AST nodes.

ECMAScript defines multiple types of functions and classes. They are split into different AST nodes to reduce ambiguity and to make the AST more readable.

Structs

ArrowFunction
An arrow function expression, as defined by the spec.
AsyncArrowFunction
An async arrow function expression, as defined by the spec.
AsyncFunctionDeclaration
An async function declaration.
AsyncFunctionExpression
An async function expression.
AsyncGeneratorDeclaration
An async generator declaration.
AsyncGeneratorExpression
An async generator expression.
ClassDeclaration
A class declaration.
ClassExpression
A class expression.
ClassFieldDefinition
A non-private class element field definition.
ClassMethodDefinition
A method definition.
FormalParameter
“Formal parameter” is a fancy way of saying “function parameter”.
FormalParameterList
A list of FormalParameters that describes the parameters of a function, as defined by the spec.
FormalParameterListFlags
Flags for a FormalParameterList.
FunctionBody
A Function body.
FunctionDeclaration
A function declaration.
FunctionExpression
A function expression.
GeneratorDeclaration
A generator declaration.
GeneratorExpression
A generator expression.
PrivateFieldDefinition
A private class element field definition.
PrivateName
A private name as defined by the spec.
StaticBlockBody
The body of a class’ static block, as defined by the spec.

Enums

ClassElement
An element that can be within a class.
ClassElementName
A class element name.