pub enum ClassElement {
MethodDefinition(ClassMethodDefinition),
FieldDefinition(ClassFieldDefinition),
StaticFieldDefinition(ClassFieldDefinition),
PrivateFieldDefinition(PrivateFieldDefinition),
PrivateStaticFieldDefinition(PrivateFieldDefinition),
StaticBlock(StaticBlockBody),
}Expand description
Variants
MethodDefinition(ClassMethodDefinition)
A method definition.
FieldDefinition(ClassFieldDefinition)
A field definition.
StaticFieldDefinition(ClassFieldDefinition)
A static field definition, accessible from the class constructor object
PrivateFieldDefinition(PrivateFieldDefinition)
A private field definition, only accessible inside the class declaration.
PrivateStaticFieldDefinition(PrivateFieldDefinition)
A private static field definition, only accessible from static methods and fields inside the class declaration.
StaticBlock(StaticBlockBody)
A static block, where a class can have initialization logic for its static fields.