pub struct ClassDeclaration { /* private fields */ }Expand description
Implementations
Sourceimpl ClassDeclaration
impl ClassDeclaration
Sourcepub fn new(
name: Identifier,
super_ref: Option<Expression>,
constructor: Option<FunctionExpression>,
elements: Box<[ClassElement]>,
) -> ClassDeclaration
pub fn new( name: Identifier, super_ref: Option<Expression>, constructor: Option<FunctionExpression>, elements: Box<[ClassElement]>, ) -> ClassDeclaration
Creates a new class declaration.
Sourcepub const fn name(&self) -> Identifier
pub const fn name(&self) -> Identifier
Returns the name of the class declaration.
Sourcepub const fn super_ref(&self) -> Option<&Expression>
pub const fn super_ref(&self) -> Option<&Expression>
Returns the super class ref of the class declaration.
Sourcepub const fn constructor(&self) -> Option<&FunctionExpression>
pub const fn constructor(&self) -> Option<&FunctionExpression>
Returns the constructor of the class declaration.
Sourcepub const fn elements(&self) -> &[ClassElement]
pub const fn elements(&self) -> &[ClassElement]
Gets the list of all fields defined on the class declaration.
Sourcepub const fn name_scope(&self) -> &Scope
pub const fn name_scope(&self) -> &Scope
Gets the scope containing the class name binding.