pub struct FormalParameterListFlags(/* private fields */);Expand description
Flags for a FormalParameterList.
Implementations
Sourceimpl FormalParameterListFlags
impl FormalParameterListFlags
Sourcepub const IS_SIMPLE: FormalParameterListFlags
pub const IS_SIMPLE: FormalParameterListFlags
Has only identifier parameters with no initialization expressions.
Sourcepub const HAS_DUPLICATES: FormalParameterListFlags
pub const HAS_DUPLICATES: FormalParameterListFlags
Has any duplicate parameters.
Sourcepub const HAS_REST_PARAMETER: FormalParameterListFlags
pub const HAS_REST_PARAMETER: FormalParameterListFlags
Has a rest parameter.
Sourcepub const HAS_EXPRESSIONS: FormalParameterListFlags
pub const HAS_EXPRESSIONS: FormalParameterListFlags
Has any initialization expression.
Sourcepub const HAS_ARGUMENTS: FormalParameterListFlags
pub const HAS_ARGUMENTS: FormalParameterListFlags
Has an argument with the name arguments.
Sourceimpl FormalParameterListFlags
impl FormalParameterListFlags
Sourcepub const fn empty() -> FormalParameterListFlags
pub const fn empty() -> FormalParameterListFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> FormalParameterListFlags
pub const fn all() -> FormalParameterListFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<FormalParameterListFlags>
pub const fn from_bits(bits: u8) -> Option<FormalParameterListFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> FormalParameterListFlags
pub const fn from_bits_truncate(bits: u8) -> FormalParameterListFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> FormalParameterListFlags
pub const fn from_bits_retain(bits: u8) -> FormalParameterListFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<FormalParameterListFlags>
pub fn from_name(name: &str) -> Option<FormalParameterListFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: FormalParameterListFlags) -> bool
pub const fn intersects(&self, other: FormalParameterListFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: FormalParameterListFlags) -> bool
pub const fn contains(&self, other: FormalParameterListFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: FormalParameterListFlags)
pub fn insert(&mut self, other: FormalParameterListFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: FormalParameterListFlags)
pub fn remove(&mut self, other: FormalParameterListFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: FormalParameterListFlags)
pub fn toggle(&mut self, other: FormalParameterListFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: FormalParameterListFlags, value: bool)
pub fn set(&mut self, other: FormalParameterListFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: FormalParameterListFlags,
) -> FormalParameterListFlags
pub const fn intersection( self, other: FormalParameterListFlags, ) -> FormalParameterListFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(
self,
other: FormalParameterListFlags,
) -> FormalParameterListFlags
pub const fn union( self, other: FormalParameterListFlags, ) -> FormalParameterListFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(
self,
other: FormalParameterListFlags,
) -> FormalParameterListFlags
pub const fn difference( self, other: FormalParameterListFlags, ) -> FormalParameterListFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: FormalParameterListFlags,
) -> FormalParameterListFlags
pub const fn symmetric_difference( self, other: FormalParameterListFlags, ) -> FormalParameterListFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> FormalParameterListFlags
pub const fn complement(self) -> FormalParameterListFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl FormalParameterListFlags
impl FormalParameterListFlags
Sourcepub const fn iter(&self) -> Iter<FormalParameterListFlags>
pub const fn iter(&self) -> Iter<FormalParameterListFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<FormalParameterListFlags>
pub const fn iter_names(&self) -> IterNames<FormalParameterListFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.