pub struct BindingLocator { /* private fields */ }Expand description
A binding locator contains all information about a binding that is needed to resolve it at runtime.
Implementations
Sourceimpl BindingLocator
impl BindingLocator
Sourcepub fn scope(&self) -> BindingLocatorScope
pub fn scope(&self) -> BindingLocatorScope
Returns the scope of the binding.
Sourcepub fn set_scope(&mut self, scope: BindingLocatorScope)
pub fn set_scope(&mut self, scope: BindingLocatorScope)
Sets the scope of the binding.
Sourcepub const fn binding_index(&self) -> u32
pub const fn binding_index(&self) -> u32
Returns the binding index of the binding.
Sourcepub fn set_binding_index(&mut self, index: u32)
pub fn set_binding_index(&mut self, index: u32)
Sets the binding index of the binding.