pub struct FunctionScopes { /* private fields */ }Expand description
A collection of function scopes.
Implementations
Sourceimpl FunctionScopes
impl FunctionScopes
Sourcepub fn function_scope(&self) -> &Scope
pub fn function_scope(&self) -> &Scope
Returns the function scope for this function.
Sourcepub fn arguments_object_accessed(&self) -> bool
pub fn arguments_object_accessed(&self) -> bool
Returns if the arguments object is accessed in this function.
Sourcepub fn requires_function_scope(&self) -> bool
pub fn requires_function_scope(&self) -> bool
Check if the creation of the function scope is required.
Sourcepub fn parameters_eval_scope(&self) -> Option<&Scope>
pub fn parameters_eval_scope(&self) -> Option<&Scope>
Returns the parameters eval scope for this function.
Sourcepub fn parameters_scope(&self) -> Option<&Scope>
pub fn parameters_scope(&self) -> Option<&Scope>
Returns the parameters scope for this function.
Sourcepub fn lexical_scope(&self) -> Option<&Scope>
pub fn lexical_scope(&self) -> Option<&Scope>
Returns the lexical scope for this function.
Sourcepub fn parameter_scope(&self) -> Scope
pub fn parameter_scope(&self) -> Scope
Returns the effective paramter scope for this function.