pub struct Case { /* private fields */ }Expand description
A case clause inside a Switch statement, as defined by the spec.
Even though every Case body is a StatementList, it doesn’t create a new lexical
environment. This means any variable declared in a Case will be considered as part of the
lexical environment of the parent Switch block.
Implementations
Sourceimpl Case
impl Case
Sourcepub const fn new(condition: Expression, body: StatementList) -> Case
pub const fn new(condition: Expression, body: StatementList) -> Case
Creates a regular Case AST node.
Sourcepub const fn default(body: StatementList) -> Case
pub const fn default(body: StatementList) -> Case
Creates a default Case AST node.
Sourcepub const fn condition(&self) -> Option<&Expression>
pub const fn condition(&self) -> Option<&Expression>
Gets the condition of the case.
If it’s a regular case returns Some with the Expression,
otherwise None is returned if it’s the default case.
Sourcepub const fn body(&self) -> &StatementList
pub const fn body(&self) -> &StatementList
Gets the statement listin the body of the case.
Sourcepub const fn is_default(&self) -> bool
pub const fn is_default(&self) -> bool
Check if the case is the default case.