pub struct DoWhileLoop { /* private fields */ }Expand description
The do...while statement creates a loop that executes a specified statement until the
test condition evaluates to false.
The condition is evaluated after executing the statement, resulting in the specified statement executing at least once.
More information:
Implementations
Sourceimpl DoWhileLoop
impl DoWhileLoop
Sourcepub const fn cond(&self) -> &Expression
pub const fn cond(&self) -> &Expression
Gets the condition of the do-while loop.
Sourcepub fn new(body: Statement, condition: Expression) -> DoWhileLoop
pub fn new(body: Statement, condition: Expression) -> DoWhileLoop
Creates a DoWhileLoop AST node.