pub struct ForOfLoop { /* private fields */ }Expand description
A for...of loop statement, as defined by the spec.
for..of statements loop over a sequence of values obtained from an iterable object (Array,
String, Map, generators).
This type combines for..of and for await...of statements in a single structure,
since for await...of is essentially the same statement but with async iterable objects
as the source of iteration.
Implementations
Sourceimpl ForOfLoop
impl ForOfLoop
Sourcepub fn new(
init: IterableLoopInitializer,
iterable: Expression,
body: Statement,
await: bool,
) -> ForOfLoop
pub fn new( init: IterableLoopInitializer, iterable: Expression, body: Statement, await: bool, ) -> ForOfLoop
Creates a new “for of” loop AST node.
Sourcepub const fn initializer(&self) -> &IterableLoopInitializer
pub const fn initializer(&self) -> &IterableLoopInitializer
Gets the initializer of the for…of loop.
Sourcepub const fn iterable(&self) -> &Expression
pub const fn iterable(&self) -> &Expression
Gets the iterable expression of the for…of loop.
Sourcepub const fn await(&self) -> bool
pub const fn await(&self) -> bool
Returns true if this “for…of” loop is an “for await…of” loop.
Sourcepub const fn iterable_scope(&self) -> Option<&Scope>
pub const fn iterable_scope(&self) -> Option<&Scope>
Return the iterable scope of the for…of loop.