pub struct ModuleItemList { /* private fields */ }Expand description
Module item list AST node.
It contains a list of module items.
More information:
Implementations
Sourceimpl ModuleItemList
impl ModuleItemList
Sourcepub const fn items(&self) -> &[ModuleItem]
pub const fn items(&self) -> &[ModuleItem]
Gets the list of module items.
Sourcepub fn exported_names(&self) -> Vec<Sym>
pub fn exported_names(&self) -> Vec<Sym>
Abstract operation ExportedNames.
Sourcepub fn exported_bindings(&self) -> HashSet<Sym, FxBuildHasher>
pub fn exported_bindings(&self) -> HashSet<Sym, FxBuildHasher>
Abstract operation ExportedBindings.
Sourcepub fn requests(&self) -> IndexSet<Sym, BuildHasherDefault<FxHasher>>
pub fn requests(&self) -> IndexSet<Sym, BuildHasherDefault<FxHasher>>
Operation ModuleRequests.
Gets the list of modules that need to be fetched by the module resolver to link this module.
Sourcepub fn import_entries(&self) -> Vec<ImportEntry>
pub fn import_entries(&self) -> Vec<ImportEntry>
Operation ImportEntries.
Gets the list of import entries of this module.
Sourcepub fn export_entries(&self) -> Vec<ExportEntry>
pub fn export_entries(&self) -> Vec<ExportEntry>
Operation ExportEntries.
Gets the list of export entries of this module.