Position

Struct Position 

pub struct Position { /* private fields */ }
A position in the ECMAScript source code.

Stores both the column number and the line number.

Similar Implementations

V8: Location

Implementations

Source

impl Position

pub const fn new(line_number: u32, column_number: u32) -> Position

Creates a new Position from Non-Zero values.

Panics

Will panic if the line number or column number is zero.

pub const fn line_number(self) -> u32

Gets the line number of the position.

pub const fn column_number(self) -> u32

Gets the column number of the position.