pub struct Script { /* private fields */ }Expand description
Implementations
Sourceimpl Script
impl Script
Sourcepub const fn new(statements: StatementList) -> Script
pub const fn new(statements: StatementList) -> Script
Creates a new ScriptNode.
Sourcepub const fn statements(&self) -> &StatementList
pub const fn statements(&self) -> &StatementList
Gets the list of statements of this ScriptNode.
Sourcepub fn statements_mut(&mut self) -> &mut StatementList
pub fn statements_mut(&mut self) -> &mut StatementList
Gets a mutable reference to the list of statements of this ScriptNode.
Sourcepub fn analyze_scope(
&mut self,
scope: &Scope,
interner: &Interner,
) -> Result<(), &'static str>
pub fn analyze_scope( &mut self, scope: &Scope, interner: &Interner, ) -> Result<(), &'static str>
Analyze the scope of the script.
Errors
Any scope or binding errors that happened during the analysis.
Sourcepub fn analyze_scope_eval(
&mut self,
strict: bool,
variable_scope: &Scope,
lexical_scope: &Scope,
annex_b_function_names: &[Sym],
interner: &Interner,
) -> Result<EvalDeclarationBindings, String>
pub fn analyze_scope_eval( &mut self, strict: bool, variable_scope: &Scope, lexical_scope: &Scope, annex_b_function_names: &[Sym], interner: &Interner, ) -> Result<EvalDeclarationBindings, String>
Analyze the scope of the script in eval mode.
Errors
Returns an error if the scope analysis fails with a syntax error.