Error

Struct Error 

pub struct Error { /* private fields */ }
A built-in Error object, per the ECMAScript spec.

This is used internally to convert between JsObject and JsNativeError correctly, but it can also be used to manually create Error objects. However, the recommended way to create them is to construct a JsNativeError first, then call JsNativeError::to_opaque, which will assign its prototype, properties and kind automatically.

For a description of every error kind and its usage, see JsNativeErrorKind.

Implementations

Source

impl Error

pub fn new(tag: ErrorKind) -> Error

Create a new Error.