pub enum ThisMode {
Lexical,
Strict,
Global,
}Expand description
Represents the [[ThisMode]] internal slot of function objects.
More information:
Variants
Lexical
The this value refers to the this value of a lexically enclosing function.
Strict
The this value is used exactly as provided by an invocation of the function.
Global
The this value of undefined or null is interpreted as a reference to the global object,
and any other this value is first passed to ToObject.
Implementations