pub struct OrderedSet { /* private fields */ }Expand description
A type wrapping indexmap::IndexSet
Implementations
Sourceimpl OrderedSet
impl OrderedSet
Sourcepub fn new() -> OrderedSet
pub fn new() -> OrderedSet
Creates a new empty OrderedSet.
Sourcepub fn with_capacity(capacity: usize) -> OrderedSet
pub fn with_capacity(capacity: usize) -> OrderedSet
Creates a new empty OrderedSet with the specified capacity.
Sourcepub fn full_len(&self) -> usize
pub fn full_len(&self) -> usize
Return the number of elements in the set, including empty elements.
Computes in O(1) time.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the set contains no elements.
Computes in O(1) time.
Sourcepub fn add(&mut self, value: JsValue) -> bool
pub fn add(&mut self, value: JsValue) -> bool
Insert a value pair in the set.
If an equivalent value already exists in the set: ???
If no equivalent value existed in the set: the new value is inserted, last in order, and false
Computes in O(1) time (amortized average).
Sourcepub fn delete(&mut self, value: &JsValue) -> bool
pub fn delete(&mut self, value: &JsValue) -> bool
Delete the value from the set and return true if successful
Return false if value is not in set.
Computes in O(n) time (average).
Sourcepub fn contains(&self, value: &JsValue) -> bool
pub fn contains(&self, value: &JsValue) -> bool
Checks if a given value is present in the set
Return true if value is present in set, false otherwise.
Computes in O(n) time (average).