pub enum TypedArrayKind {
Int8,
Uint8,
Uint8Clamped,
Int16,
Uint16,
Int32,
Uint32,
BigInt64,
BigUint64,
Float16,
Float32,
Float64,
}Expand description
List of all typed array kinds.
Variants
Int8
8-bit signed integers.
Uint8
8-bit unsigned integers.
Uint8Clamped
8-bit unsigned integers clamped to 0–255.
Int16
16-bit signed integers.
Uint16
16-bit unsigned integers.
Int32
32-bit signed integers.
Uint32
32-bit unsigned integers.
BigInt64
64-bit signed integers in the platform byte order.
BigUint64
64-bit unsigned integers in the platform byte order.
Float16
16-bit floating point numbers in the platform byte order.
Float32
32-bit floating point numbers in the platform byte order.
Float64
64-bit floating point numbers in the platform byte order.