#[derive(TryFromJs)]
{
// Attributes available to this derive:
#[boa]
}
Derives the TryFromJs trait, with the #[boa()] attribute.
Panics
It will panic if the user tries to derive the TryFromJs trait in an enum or a tuple struct.