TryIntoJs

Derive Macro TryIntoJs 

#[derive(TryIntoJs)]
{
    // Attributes available to this derive:
    #[boa]
}
Derives the TryIntoJs trait, with the #[boa()] attribute.

Panics

It will panic if the user tries to derive the TryIntoJs trait in an enum or a tuple struct.