#[non_exhaustive]pub enum JsErasedNativeErrorKind {
Aggregate(Vec<JsErasedError>),
Error,
Eval,
Range,
Reference,
Syntax,
Type,
Uri,
RuntimeLimit,
}Expand description
Erased version of JsNativeErrorKind
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Aggregate(Vec<JsErasedError>)
A collection of errors wrapped in a single error.
More information:
Error
A generic error. Commonly used as the base for custom exceptions.
More information:
Eval
An error related to the global function eval().
More information:
Range
An error thrown when a value is outside its valid range.
More information:
Reference
An error representing an invalid de-reference of a variable.
More information:
Syntax
An error representing an invalid syntax in the Javascript language.
More information:
Type
An error thrown when a variable or argument is not of a valid type.
More information:
Uri
An error thrown when the encodeURI() and decodeURI() functions receive
invalid parameters.
More information:
RuntimeLimit
Error thrown when a runtime limit is exceeded. It’s not a valid JS error variant.