JsHeaders

Struct JsHeaders 

pub struct JsHeaders { /* private fields */ }
A JavaScript wrapper for the Headers object.

Implementations

Source

impl JsHeaders

pub fn from_http(http: HeaderMap) -> JsHeaders

Creates a JsHeaders from an internal http::HeaderMap. Takes ownership of the inner map.

Source

impl JsHeaders

pub fn append( &mut self, key: Convert<String>, value: Convert<String>, ) -> Result<(), JsError>

Appends a new value onto an existing header inside a Headers object, or adds the header if it does not already exist.

Errors

If the key or value is not valid ASCII, an error is returned.

pub fn delete(&mut self, key: Convert<String>) -> Result<(), JsError>

Deletes a header from a Headers object.

Errors

If the key is not valid ASCII, an error is returned.

pub fn entries(&self, context: &mut Context) -> JsValue

Returns an iterator allowing to go through all key/value pairs contained in this object.

pub fn for_each( this: JsClass<JsHeaders>, callback: TypedJsFunction<(JsString, JsString, JsObject), ()>, this_arg: Option<JsValue>, context: &mut Context, ) -> Result<(), JsError>

Executes a provided function once for each key/value pair in the Headers object.

Errors

If the callback function returns an error, it is returned.

pub fn get( &self, key: JsValue, context: &mut Context, ) -> Result<JsValue, JsError>

Returns a byte string of all the values in a header within a Headers object with a given name. If the requested header doesn’t exist in the Headers object, it returns null.

Errors

If the key is not valid ASCII, an error is returned.

pub fn has(&self, key: Convert<String>) -> Result<bool, JsError>

Returns a boolean stating whether a Headers object contains a certain header.

Errors

If the key isn’t a valid header name, this will error.