TestFetcher

Struct TestFetcher 

pub struct TestFetcher { /* private fields */ }
A crate::fetch::Fetcher implementation for tests. Maps a URL to a response, and record requests received for later use.

The actual safety of this implementation is not guaranteed, as it is only intended for testing purposes.

Implementations

Source

impl TestFetcher

pub fn add_response(&mut self, url: Uri, response: Response<Vec<u8>>)

Add a response mapping for a URL.