ToInternedString

Trait ToInternedString 

pub trait ToInternedString {
    // Required method
    fn to_interned_string(&self, interner: &Interner) -> String;
}
Converts a given element to a string using an interner.

Required Methods

fn to_interned_string(&self, interner: &Interner) -> String

Converts a given element to a string using an interner.

Implementors

Source

impl ToInternedString for Binding

Source

impl ToInternedString for LexicalDeclaration

Source

impl ToInternedString for PropertyAccess

Source

impl ToInternedString for LiteralKind

Source

impl ToInternedString for AssignTarget

Source

impl ToInternedString for UpdateTarget

Source

impl ToInternedString for ClassElementName

Source

impl ToInternedString for ArrayPatternElement

Source

impl ToInternedString for ObjectPatternElement

Source

impl ToInternedString for Pattern

Source

impl ToInternedString for PropertyName

Source

impl ToInternedString for LabelledItem

Source

impl ToInternedString for ForLoopInitializer

Source

impl ToInternedString for IterableLoopInitializer

Source

impl ToInternedString for VarDeclaration

Source

impl ToInternedString for Variable

Source

impl ToInternedString for VariableList

Source

impl ToInternedString for PrivatePropertyAccess

Source

impl ToInternedString for SimplePropertyAccess

Source

impl ToInternedString for SuperPropertyAccess

Source

impl ToInternedString for ArrayLiteral

Source

impl ToInternedString for Literal

Source

impl ToInternedString for TemplateLiteral

Source

impl ToInternedString for Assign

Source

impl ToInternedString for Binary

Source

impl ToInternedString for BinaryInPrivate

Source

impl ToInternedString for Conditional

Source

impl ToInternedString for Unary

Source

impl ToInternedString for Update

Source

impl ToInternedString for Await

Source

impl ToInternedString for Call

Source

impl ToInternedString for Identifier

Source

impl ToInternedString for ImportCall

Source

impl ToInternedString for ImportMeta

Source

impl ToInternedString for New

Source

impl ToInternedString for NewTarget

Source

impl ToInternedString for Optional

Source

impl ToInternedString for OptionalOperation

Source

impl ToInternedString for Parenthesized

Source

impl ToInternedString for RegExpLiteral

Source

impl ToInternedString for Spread

Source

impl ToInternedString for SuperCall

Source

impl ToInternedString for TaggedTemplate

Source

impl ToInternedString for This

Source

impl ToInternedString for Yield

Source

impl ToInternedString for FormalParameter

Source

impl ToInternedString for ArrayPattern

Source

impl ToInternedString for ObjectPattern

Source

impl ToInternedString for Break

Source

impl ToInternedString for Continue

Source

impl ToInternedString for Labelled

Source

impl ToInternedString for Return

Source

impl ToInternedString for Throw

Source

impl<T> ToInternedString for T