JsProxyBuilder

Struct JsProxyBuilder 

pub struct JsProxyBuilder { /* private fields */ }
Utility builder to create JsProxy objects from native functions.

This builder can be used when you need to create Proxy objects from Rust instead of Javascript, which should generate faster trap functions than its Javascript counterparts.

Implementations

Source

impl JsProxyBuilder

pub fn new(target: JsObject) -> JsProxyBuilder

Create a new ProxyBuilder with every trap set to undefined.

pub fn apply( self, apply: fn(&JsValue, &[JsValue], &mut Context) -> Result<JsValue, JsError>, ) -> JsProxyBuilder

Set the apply proxy trap to the specified native function.

More information:

Note

If the target object is not a function, then apply will be ignored when trying to call the proxy, which will throw a type error.

pub fn construct( self, construct: fn(&JsValue, &[JsValue], &mut Context) -> Result<JsValue, JsError>, ) -> JsProxyBuilder

Set the construct proxy trap to the specified native function.

More information:

Note

If the target object is not a constructor, then construct will be ignored when trying to construct an object using the proxy, which will throw a type error.

pub fn define_property( self, define_property: fn(&JsValue, &[JsValue], &mut Context) -> Result<JsValue, JsError>, ) -> JsProxyBuilder

Set the defineProperty proxy trap to the specified native function.

More information:

pub fn delete_property( self, delete_property: fn(&JsValue, &[JsValue], &mut Context) -> Result<JsValue, JsError>, ) -> JsProxyBuilder

Set the deleteProperty proxy trap to the specified native function.

More information:

pub fn get( self, get: fn(&JsValue, &[JsValue], &mut Context) -> Result<JsValue, JsError>, ) -> JsProxyBuilder

Set the get proxy trap to the specified native function.

More information:

pub fn get_own_property_descriptor( self, get_own_property_descriptor: fn(&JsValue, &[JsValue], &mut Context) -> Result<JsValue, JsError>, ) -> JsProxyBuilder

Set the getOwnPropertyDescriptor proxy trap to the specified native function.

More information:

pub fn get_prototype_of( self, get_prototype_of: fn(&JsValue, &[JsValue], &mut Context) -> Result<JsValue, JsError>, ) -> JsProxyBuilder

Set the getPrototypeOf proxy trap to the specified native function.

More information:

pub fn has( self, has: fn(&JsValue, &[JsValue], &mut Context) -> Result<JsValue, JsError>, ) -> JsProxyBuilder

Set the has proxy trap to the specified native function.

More information:

pub fn is_extensible( self, is_extensible: fn(&JsValue, &[JsValue], &mut Context) -> Result<JsValue, JsError>, ) -> JsProxyBuilder

Set the isExtensible proxy trap to the specified native function.

More information:

pub fn own_keys( self, own_keys: fn(&JsValue, &[JsValue], &mut Context) -> Result<JsValue, JsError>, ) -> JsProxyBuilder

Set the ownKeys proxy trap to the specified native function.

More information:

pub fn prevent_extensions( self, prevent_extensions: fn(&JsValue, &[JsValue], &mut Context) -> Result<JsValue, JsError>, ) -> JsProxyBuilder

Set the preventExtensions proxy trap to the specified native function.

More information:

pub fn set( self, set: fn(&JsValue, &[JsValue], &mut Context) -> Result<JsValue, JsError>, ) -> JsProxyBuilder

Set the set proxy trap to the specified native function.

More information:

pub fn set_prototype_of( self, set_prototype_of: fn(&JsValue, &[JsValue], &mut Context) -> Result<JsValue, JsError>, ) -> JsProxyBuilder

Set the setPrototypeOf proxy trap to the specified native function.

More information:

pub fn build(self, context: &mut Context) -> JsProxy

Build a JsObject of kind Proxy.

Equivalent to the Proxy ( target, handler ) constructor, but returns a JsObject in case there’s a need to manipulate the returned object inside Rust code.

pub fn build_revocable(self, context: &mut Context) -> JsRevocableProxy

Builds a JsObject of kind Proxy and a JsFunction that, when called, disables the proxy of the object.

Equivalent to the Proxy.revocable ( target, handler ) static method, but returns a JsObject for the proxy and a JsFunction for the revoker in case there’s a need to manipulate the returned objects inside Rust code.