pub struct FunctionBinding { /* private fields */ }Expand description
The functions binding.
Specifies what is the name of the function object (name property),
and the binding name of the function object which can be different
from the function name.
The only way to construct this is with the From trait.
There are two implementations:
- From a single type
Twhich implementsInto<FunctionBinding>which sets the binding name and the function name to the same value. - From a tuple
(B: Into<PropertyKey>, N: Into<JsString>), where theBis the binding name and theNis the function name.