pub struct OptimizerOptions(/* private fields */);Expand description
Optimizer options.
Implementations
Sourceimpl OptimizerOptions
impl OptimizerOptions
Sourcepub const STATISTICS: OptimizerOptions
pub const STATISTICS: OptimizerOptions
Print statistics to stdout.
Sourcepub const CONSTANT_FOLDING: OptimizerOptions
pub const CONSTANT_FOLDING: OptimizerOptions
Apply constant folding optimization.
Sourcepub const OPTIMIZE_ALL: OptimizerOptions
pub const OPTIMIZE_ALL: OptimizerOptions
Apply all optimizations.
Sourceimpl OptimizerOptions
impl OptimizerOptions
Sourcepub const fn empty() -> OptimizerOptions
pub const fn empty() -> OptimizerOptions
Get a flags value with all bits unset.
Sourcepub const fn all() -> OptimizerOptions
pub const fn all() -> OptimizerOptions
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<OptimizerOptions>
pub const fn from_bits(bits: u8) -> Option<OptimizerOptions>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> OptimizerOptions
pub const fn from_bits_truncate(bits: u8) -> OptimizerOptions
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> OptimizerOptions
pub const fn from_bits_retain(bits: u8) -> OptimizerOptions
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<OptimizerOptions>
pub fn from_name(name: &str) -> Option<OptimizerOptions>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: OptimizerOptions) -> bool
pub const fn intersects(&self, other: OptimizerOptions) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: OptimizerOptions) -> bool
pub const fn contains(&self, other: OptimizerOptions) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: OptimizerOptions)
pub fn insert(&mut self, other: OptimizerOptions)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: OptimizerOptions)
pub fn remove(&mut self, other: OptimizerOptions)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: OptimizerOptions)
pub fn toggle(&mut self, other: OptimizerOptions)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: OptimizerOptions, value: bool)
pub fn set(&mut self, other: OptimizerOptions, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: OptimizerOptions) -> OptimizerOptions
pub const fn intersection(self, other: OptimizerOptions) -> OptimizerOptions
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: OptimizerOptions) -> OptimizerOptions
pub const fn union(self, other: OptimizerOptions) -> OptimizerOptions
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: OptimizerOptions) -> OptimizerOptions
pub const fn difference(self, other: OptimizerOptions) -> OptimizerOptions
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: OptimizerOptions,
) -> OptimizerOptions
pub const fn symmetric_difference( self, other: OptimizerOptions, ) -> OptimizerOptions
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> OptimizerOptions
pub const fn complement(self) -> OptimizerOptions
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl OptimizerOptions
impl OptimizerOptions
Sourcepub const fn iter(&self) -> Iter<OptimizerOptions>
pub const fn iter(&self) -> Iter<OptimizerOptions>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<OptimizerOptions>
pub const fn iter_names(&self) -> IterNames<OptimizerOptions>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.