pub enum TokenKind {
Show 14 variants
BooleanLiteral((bool, ContainsEscapeSequence)),
EOF,
IdentifierName((Sym, ContainsEscapeSequence)),
PrivateIdentifier(Sym),
Keyword((Keyword, bool)),
NullLiteral(ContainsEscapeSequence),
NumericLiteral(Numeric),
Punctuator(Punctuator),
StringLiteral((Sym, EscapeSequence)),
TemplateNoSubstitution(TemplateString),
TemplateMiddle(TemplateString),
RegularExpressionLiteral(Sym, Sym),
LineTerminator,
Comment,
}Expand description
Represents the type of Token and the data it has inside.
Variants
BooleanLiteral((bool, ContainsEscapeSequence))
A boolean literal, which is either true or false.
EOF
The end of the file.
IdentifierName((Sym, ContainsEscapeSequence))
An identifier name.
PrivateIdentifier(Sym)
Keyword((Keyword, bool))
A keyword and a flag if the keyword contains unicode escaped chars.
For more information, see Keyword.
NullLiteral(ContainsEscapeSequence)
The null literal.
NumericLiteral(Numeric)
A numeric literal.
Punctuator(Punctuator)
A piece of punctuation
StringLiteral((Sym, EscapeSequence))
TemplateNoSubstitution(TemplateString)
A part of a template literal without substitution.
TemplateMiddle(TemplateString)
The part of a template literal between substitutions
RegularExpressionLiteral(Sym, Sym)
A regular expression, consisting of body and flags.
LineTerminator
Indicates a line terminator (\n).
Comment
Indicates a comment, the content isn’t stored.
Implementations
Sourceimpl TokenKind
impl TokenKind
Sourcepub const fn boolean_literal(lit: bool) -> TokenKind
pub const fn boolean_literal(lit: bool) -> TokenKind
Creates a BooleanLiteral token kind.
Sourcepub const fn identifier(ident: Sym) -> TokenKind
pub const fn identifier(ident: Sym) -> TokenKind
Creates an Identifier token type.
Sourcepub fn numeric_literal<L>(lit: L) -> TokenKind
pub fn numeric_literal<L>(lit: L) -> TokenKind
Creates a NumericLiteral token kind.
Sourcepub const fn punctuator(punc: Punctuator) -> TokenKind
pub const fn punctuator(punc: Punctuator) -> TokenKind
Creates a Punctuator token type.
Sourcepub const fn string_literal(
lit: Sym,
escape_sequence: EscapeSequence,
) -> TokenKind
pub const fn string_literal( lit: Sym, escape_sequence: EscapeSequence, ) -> TokenKind
Creates a StringLiteral token type.
Sourcepub const fn template_middle(template_string: TemplateString) -> TokenKind
pub const fn template_middle(template_string: TemplateString) -> TokenKind
Creates a TemplateMiddle token type.
Sourcepub const fn template_no_substitution(
template_string: TemplateString,
) -> TokenKind
pub const fn template_no_substitution( template_string: TemplateString, ) -> TokenKind
Creates a TemplateNoSubstitution token type.
Sourcepub const fn regular_expression_literal(body: Sym, flags: Sym) -> TokenKind
pub const fn regular_expression_literal(body: Sym, flags: Sym) -> TokenKind
Creates a RegularExpressionLiteral token kind.
Sourcepub const fn line_terminator() -> TokenKind
pub const fn line_terminator() -> TokenKind
Creates a LineTerminator token kind.