ReadChar

Trait ReadChar 

pub trait ReadChar {
    // Required method
    fn next_char(&mut self) -> Result<Option<u32>, Error>;
}
This trait is used to abstract over the different types of input readers.

Required Methods

fn next_char(&mut self) -> Result<Option<u32>, Error>

Retrieves the next unicode code point. Returns None if the end of the input is reached.

Errors

Returns an error if the next input in the input is not a valid unicode code point.

Implementors

Source

impl ReadChar for UTF16Input<'_>

Source

impl<R> ReadChar for UTF8Input<R>
where R: Read,