pub struct JsValueStore(/* private fields */);Expand description
A JsValue-like structure that can rebuild its value given any Context.
It essentially stores the value itself and its original type. During
reconstruction, the constructors of the new Context will be used.
This follows the rules of the structured clone algorithm, but does not
require a Context to copy/move, and can be Send between threads.
It is not serializable as it allows recursive values.
To transform a JsValue into a JsValueStore, the application MUST
pass in the context of the initial value. To transform it back to a
JsValue, the application MUST pass the context that will contain
all prototypes for the new types (e.g. Object).
Implementations
Sourceimpl JsValueStore
impl JsValueStore
Sourcepub fn try_from_js(
value: &JsValue,
context: &mut Context,
transfer: Vec<JsValue>,
) -> Result<JsValueStore, JsError>
pub fn try_from_js( value: &JsValue, context: &mut Context, transfer: Vec<JsValue>, ) -> Result<JsValueStore, JsError>
Create a context-free JsValue equivalent from an existing JsValue and the
Context that was used to create it. The transfer argument allows for
transferring ownership of the inner data to the context-free value instead of
cloning it. By default, if a value isn’t in the transfer vector, it is cloned.
Errors
Any errors related to transferring or cloning a value’s inner data.