Module string

Module string 

This module contains the js_string macro and the js_str macro.

The js_string macro is used when you need to create a new JsString, and the js_str macro is used for const conversions of string literals to JsStr.

Structs

CommonJsStringBuilder
Common JsString builder that accepts multiple variant of string or character.
Iter
Iterator over a JsStr.
JsStr
This is equivalent to Rust’s &str.
JsString
A Latin1 or UTF-16–encoded, reference counted, immutable string.
RawJsString
The raw representation of a JsString in the heap.
StaticJsStrings
List of commonly used strings in Javascript code.

Enums

CodePoint
Represents a Unicode codepoint within a JsString, which could be a valid ‘Unicode scalar value’, or an unpaired surrogate.
JsStrVariant
Inner representation of a JsStr.

Type Aliases

Latin1JsStringBuilder
Latin1 encoded JsStringBuilder
Utf16JsStringBuilder
UTF-16 encoded JsStringBuilder