StaticJsStrings

Struct StaticJsStrings 

pub struct StaticJsStrings;
List of commonly used strings in Javascript code.

Any strings defined here are used as a static JsString instead of allocating on the heap.

Implementations

Source

impl StaticJsStrings

pub const EMPTY_STRING: JsString

Gets the static JsString for "".

pub const LENGTH: JsString

Gets the static JsString for "length".

pub const SYMBOL_ASYNC_ITERATOR: JsString

Gets the static JsString for "Symbol.asyncIterator".

pub const SYMBOL_HAS_INSTANCE: JsString

Gets the static JsString for "Symbol.hasInstance".

pub const SYMBOL_IS_CONCAT_SPREADABLE: JsString

Gets the static JsString for "Symbol.isConcatSpreadable".

pub const SYMBOL_ITERATOR: JsString

Gets the static JsString for "Symbol.iterator".

pub const SYMBOL_MATCH: JsString

Gets the static JsString for "Symbol.match".

pub const SYMBOL_MATCH_ALL: JsString

Gets the static JsString for "Symbol.matchAll".

pub const SYMBOL_REPLACE: JsString

Gets the static JsString for "Symbol.replace".

Gets the static JsString for "Symbol.search".

pub const SYMBOL_SPECIES: JsString

Gets the static JsString for "Symbol.species".

pub const SYMBOL_SPLIT: JsString

Gets the static JsString for "Symbol.split".

pub const SYMBOL_TO_PRIMITIVE: JsString

Gets the static JsString for "Symbol.toPrimitive".

pub const SYMBOL_TO_STRING_TAG: JsString

Gets the static JsString for "Symbol.toStringTag".

pub const SYMBOL_UNSCOPABLES: JsString

Gets the static JsString for "Symbol.unscopables".

pub const FN_SYMBOL_ASYNC_ITERATOR: JsString

Gets the static JsString for "[Symbol.asyncIterator]".

pub const FN_SYMBOL_HAS_INSTANCE: JsString

Gets the static JsString for "[Symbol.hasInstance]".

pub const FN_SYMBOL_IS_CONCAT_SPREADABLE: JsString

Gets the static JsString for "[Symbol.isConcatSpreadable]".

pub const FN_SYMBOL_ITERATOR: JsString

Gets the static JsString for "[Symbol.iterator]".

pub const FN_SYMBOL_MATCH: JsString

Gets the static JsString for "[Symbol.match]".

pub const FN_SYMBOL_MATCH_ALL: JsString

Gets the static JsString for "[Symbol.matchAll]".

pub const FN_SYMBOL_REPLACE: JsString

Gets the static JsString for "[Symbol.replace]".

Gets the static JsString for "[Symbol.search]".

pub const FN_SYMBOL_SPECIES: JsString

Gets the static JsString for "[Symbol.species]".

pub const FN_SYMBOL_SPLIT: JsString

Gets the static JsString for "[Symbol.split]".

pub const FN_SYMBOL_TO_PRIMITIVE: JsString

Gets the static JsString for "[Symbol.toPrimitive]".

pub const FN_SYMBOL_TO_STRING_TAG: JsString

Gets the static JsString for "[Symbol.toStringTag]".

pub const FN_SYMBOL_UNSCOPABLES: JsString

Gets the static JsString for "[Symbol.unscopables]".

pub const ARRAY: JsString

Gets the static JsString for "Array".

pub const ARRAY_BUFFER: JsString

Gets the static JsString for "ArrayBuffer".

pub const SHARED_ARRAY_BUFFER: JsString

Gets the static JsString for "SharedArrayBuffer".

pub const ASYNC_FUNCTION: JsString

Gets the static JsString for "AsyncFunction".

pub const ASYNC_GENERATOR: JsString

Gets the static JsString for "AsyncGenerator".

pub const ASYNC_GENERATOR_FUNCTION: JsString

Gets the static JsString for "AsyncGeneratorFunction".

pub const ATOMICS: JsString

Gets the static JsString for "Atomics".

pub const BIG_INT: JsString

Gets the static JsString for "BigInt".

pub const BOOLEAN: JsString

Gets the static JsString for "Boolean".

pub const DATA_VIEW: JsString

Gets the static JsString for "DataView".

pub const DATE: JsString

Gets the static JsString for "Date".

pub const ERROR: JsString

Gets the static JsString for "Error".

pub const AGGREGATE_ERROR: JsString

Gets the static JsString for "AggregateError".

pub const EVAL_ERROR: JsString

Gets the static JsString for "EvalError".

pub const RANGE_ERROR: JsString

Gets the static JsString for "RangeError".

pub const REFERENCE_ERROR: JsString

Gets the static JsString for "ReferenceError".

pub const SYNTAX_ERROR: JsString

Gets the static JsString for "SyntaxError".

pub const TYPE_ERROR: JsString

Gets the static JsString for "TypeError".

pub const URI_ERROR: JsString

Gets the static JsString for "URIError".

pub const ESCAPE: JsString

Gets the static JsString for "escape".

pub const UNESCAPE: JsString

Gets the static JsString for "unescape".

pub const EVAL: JsString

Gets the static JsString for "eval".

pub const FUNCTION: JsString

Gets the static JsString for "Function".

pub const GENERATOR: JsString

Gets the static JsString for "Generator".

pub const GENERATOR_FUNCTION: JsString

Gets the static JsString for "GeneratorFunction".

pub const INTL: JsString

Gets the static JsString for "Intl".

pub const COLLATOR: JsString

Gets the static JsString for "Collator".

pub const LIST_FORMAT: JsString

Gets the static JsString for "ListFormat".

pub const LOCALE: JsString

Gets the static JsString for "Locale".

pub const PLURAL_RULES: JsString

Gets the static JsString for "PluralRules".

pub const SEGMENTER: JsString

Gets the static JsString for "Segmenter".

pub const DATE_TIME_FORMAT: JsString

Gets the static JsString for "DateTimeFormat".

pub const JSON: JsString

Gets the static JsString for "JSON".

pub const MAP: JsString

Gets the static JsString for "Map".

pub const MATH: JsString

Gets the static JsString for "Math".

pub const NUMBER: JsString

Gets the static JsString for "Number".

pub const NUMBER_FORMAT: JsString

Gets the static JsString for "NumberFormat".

pub const IS_FINITE: JsString

Gets the static JsString for "isFinite".

pub const IS_NAN: JsString

Gets the static JsString for "isNaN".

pub const PARSE_INT: JsString

Gets the static JsString for "parseInt".

pub const PARSE_FLOAT: JsString

Gets the static JsString for "parseFloat".

pub const OBJECT: JsString

Gets the static JsString for "Object".

pub const PROMISE: JsString

Gets the static JsString for "Promise".

pub const PROXY: JsString

Gets the static JsString for "Proxy".

pub const REFLECT: JsString

Gets the static JsString for "Reflect".

pub const REG_EXP: JsString

Gets the static JsString for "RegExp".

pub const SET: JsString

Gets the static JsString for "Set".

pub const STRING: JsString

Gets the static JsString for "String".

pub const SYMBOL: JsString

Gets the static JsString for "Symbol".

pub const TYPED_ARRAY: JsString

Gets the static JsString for "TypedArray".

pub const INT8_ARRAY: JsString

Gets the static JsString for "Int8Array".

pub const UINT8_ARRAY: JsString

Gets the static JsString for "Uint8Array".

pub const UINT8_CLAMPED_ARRAY: JsString

Gets the static JsString for "Uint8ClampedArray".

pub const INT16_ARRAY: JsString

Gets the static JsString for "Int16Array".

pub const UINT16_ARRAY: JsString

Gets the static JsString for "Uint16Array".

pub const INT32_ARRAY: JsString

Gets the static JsString for "Int32Array".

pub const UINT32_ARRAY: JsString

Gets the static JsString for "Uint32Array".

pub const BIG_INT64_ARRAY: JsString

Gets the static JsString for "BigInt64Array".

pub const BIG_UINT64_ARRAY: JsString

Gets the static JsString for "BigUint64Array".

pub const FLOAT16_ARRAY: JsString

Gets the static JsString for "Float16Array".

pub const FLOAT32_ARRAY: JsString

Gets the static JsString for "Float32Array".

pub const FLOAT64_ARRAY: JsString

Gets the static JsString for "Float64Array".

pub const ENCODE_URI: JsString

Gets the static JsString for "encodeURI".

pub const ENCODE_URI_COMPONENT: JsString

Gets the static JsString for "encodeURIComponent".

pub const DECODE_URI: JsString

Gets the static JsString for "decodeURI".

pub const DECODE_URI_COMPONENT: JsString

Gets the static JsString for "decodeURIComponent".

pub const WEAK_REF: JsString

Gets the static JsString for "WeakRef".

pub const WEAK_MAP: JsString

Gets the static JsString for "WeakMap".

pub const WEAK_SET: JsString

Gets the static JsString for "WeakSet".

pub const TEMPORAL: JsString

Gets the static JsString for "Temporal".

pub const NOW_TAG: JsString

Gets the static JsString for "Temporal.Now".

pub const INSTANT_TAG: JsString

Gets the static JsString for "Temporal.Instant".

pub const DURATION_TAG: JsString

Gets the static JsString for "Temporal.Duration".

pub const PLAIN_DATE_TAG: JsString

Gets the static JsString for "Temporal.PlainDate".

pub const PLAIN_DATETIME_TAG: JsString

Gets the static JsString for "Temporal.PlainDateTime".

pub const PLAIN_TIME_TAG: JsString

Gets the static JsString for "Temporal.PlainTime".

pub const PLAIN_YM_TAG: JsString

Gets the static JsString for "Temporal.PlainYearMonth".

pub const PLAIN_MD_TAG: JsString

Gets the static JsString for "Temporal.PlainMonthDay".

pub const ZONED_DT_TAG: JsString

Gets the static JsString for "Temporal.ZonedDateTime".

pub const NOW_NAME: JsString

Gets the static JsString for "Now".

pub const INSTANT_NAME: JsString

Gets the static JsString for "Instant".

pub const DURATION_NAME: JsString

Gets the static JsString for "Duration".

pub const PLAIN_DATE_NAME: JsString

Gets the static JsString for "PlainDate".

pub const PLAIN_DATETIME_NAME: JsString

Gets the static JsString for "PlainDateTime".

pub const PLAIN_TIME_NAME: JsString

Gets the static JsString for "PlainTime".

pub const PLAIN_YM_NAME: JsString

Gets the static JsString for "PlainYearMonth".

pub const PLAIN_MD_NAME: JsString

Gets the static JsString for "PlainMonthDay".

pub const ZONED_DT_NAME: JsString

Gets the static JsString for "ZonedDateTime".

pub fn get_string(string: &JsStr<'_>) -> Option<JsString>

Gets the JsString corresponding to string, or None if the string doesn’t exist inside the static array.