ConsoleState

Struct ConsoleState 

pub struct ConsoleState { /* private fields */ }
The current state of the console, passed to the logger backend. This should not be copied or cloned. References are only valid for the current logging call.

Implementations

Source

impl ConsoleState

pub fn indent(&self) -> usize

Returns the indentation level that should be applied to logging.

pub fn groups(&self) -> &Vec<String>

Returns the current list of groups.

pub fn count_map(&self) -> &HashMap<JsString, u32, FxBuildHasher>

Returns the count map.

pub fn timer_map(&self) -> &HashMap<JsString, u128, FxBuildHasher>

Returns the timer map.