DefaultLogger

Struct DefaultLogger 

pub struct DefaultLogger;
The default implementation for logging from the console.

Implements the Logger trait and output errors to stderr and all the others to stdout. Will add indentation based on the number of groups.