pub struct JsSymbol { /* private fields */ }Expand description
This represents a JavaScript symbol primitive.
Implementations
Sourceimpl JsSymbol
impl JsSymbol
Sourcepub fn new(description: Option<JsString>) -> Option<JsSymbol>
pub fn new(description: Option<JsString>) -> Option<JsSymbol>
Creates a new symbol.
Returns None if the maximum number of possible symbols has been reached (u64::MAX).
Sourcepub fn description(&self) -> Option<JsString>
pub fn description(&self) -> Option<JsString>
Returns the Symbol description.
Sourcepub fn fn_name(&self) -> JsString
pub fn fn_name(&self) -> JsString
Returns the Symbol as a function name.
Equivalent to [description], but returns the empty string if the symbol doesn’t have a
description.
Sourcepub fn descriptive_string(&self) -> JsString
pub fn descriptive_string(&self) -> JsString
Sourcepub const fn async_iterator() -> JsSymbol
pub const fn async_iterator() -> JsSymbol
Gets the static JsSymbol for "Symbol.asyncIterator".
Sourcepub const fn has_instance() -> JsSymbol
pub const fn has_instance() -> JsSymbol
Gets the static JsSymbol for "Symbol.hasInstance".
Sourcepub const fn is_concat_spreadable() -> JsSymbol
pub const fn is_concat_spreadable() -> JsSymbol
Gets the static JsSymbol for "Symbol.isConcatSpreadable".
Sourcepub const fn to_primitive() -> JsSymbol
pub const fn to_primitive() -> JsSymbol
Gets the static JsSymbol for "Symbol.toPrimitive".
Sourcepub const fn to_string_tag() -> JsSymbol
pub const fn to_string_tag() -> JsSymbol
Gets the static JsSymbol for "Symbol.toStringTag".
Sourcepub const fn unscopables() -> JsSymbol
pub const fn unscopables() -> JsSymbol
Gets the static JsSymbol for "Symbol.unscopables".