pub enum TextDecoder {
Utf8,
Utf16Le,
Utf16Be,
}Expand description
The TextDecoder class represents an encoder for a specific method, that is
a specific character encoding, like utf-8.
Variants
Utf8
Decode bytes encoded as UTF-8 into strings.
Utf16Le
Decode bytes encoded as UTF-16 (little endian) into strings.
Utf16Be
Decode bytes encoded as UTF-16 (big endian) into strings.
Implementations
Sourceimpl TextDecoder
impl TextDecoder
Sourcepub fn constructor(
encoding: Option<JsString>,
_options: Option<JsObject>,
) -> Result<TextDecoder, JsError>
pub fn constructor( encoding: Option<JsString>, _options: Option<JsObject>, ) -> Result<TextDecoder, JsError>
The TextDecoder() constructor returns a new TextDecoder object.
Errors
This will return an error if the encoding or options are invalid or unsupported.
Sourcepub fn encoding(&self) -> JsString
pub fn encoding(&self) -> JsString
The TextDecoder.encoding read-only property returns a string containing
the name of the character encoding that this decoder will use.