pub struct JsHeaders { /* private fields */ }Expand description
A JavaScript wrapper for the Headers object.
Implementations
Sourceimpl JsHeaders
impl JsHeaders
Sourcepub fn append(
&mut self,
key: Convert<String>,
value: Convert<String>,
) -> Result<(), JsError>
pub fn append( &mut self, key: Convert<String>, value: Convert<String>, ) -> Result<(), JsError>
Appends a new value onto an existing header inside a Headers object, or adds the header if it does not already exist.
Errors
If the key or value is not valid ASCII, an error is returned.
Sourcepub fn delete(&mut self, key: Convert<String>) -> Result<(), JsError>
pub fn delete(&mut self, key: Convert<String>) -> Result<(), JsError>
Deletes a header from a Headers object.
Errors
If the key is not valid ASCII, an error is returned.
Sourcepub fn entries(&self, context: &mut Context) -> JsValue
pub fn entries(&self, context: &mut Context) -> JsValue
Returns an iterator allowing to go through all key/value pairs contained in this object.
Sourcepub fn for_each(
this: JsClass<JsHeaders>,
callback: TypedJsFunction<(JsString, JsString, JsObject), ()>,
this_arg: Option<JsValue>,
context: &mut Context,
) -> Result<(), JsError>
pub fn for_each( this: JsClass<JsHeaders>, callback: TypedJsFunction<(JsString, JsString, JsObject), ()>, this_arg: Option<JsValue>, context: &mut Context, ) -> Result<(), JsError>
Executes a provided function once for each key/value pair in the Headers object.
Errors
If the callback function returns an error, it is returned.
Sourcepub fn get(
&self,
key: JsValue,
context: &mut Context,
) -> Result<JsValue, JsError>
pub fn get( &self, key: JsValue, context: &mut Context, ) -> Result<JsValue, JsError>
Returns a byte string of all the values in a header within a Headers object with a given name. If the requested header doesn’t exist in the Headers object, it returns null.
Errors
If the key is not valid ASCII, an error is returned.