pub struct TestFetcher { /* private fields */ }Expand description
A crate::fetch::Fetcher implementation for tests. Maps a URL to a response,
and record requests received for later use.
The actual safety of this implementation is not guaranteed, as it is only intended for testing purposes.
Implementations
Sourceimpl TestFetcher
impl TestFetcher