pub enum IndexedProperties {
DenseI32(ThinVec<i32>),
DenseF64(ThinVec<f64>),
DenseElement(ThinVec<JsValue>),
Sparse(Box<HashMap<u32, PropertyDescriptor, FxBuildHasher>>),
}Expand description
This represents all the indexed properties.
The index properties can be stored in two storage methods:
Dense Storage
Dense storage holds a contiguous array of properties where the index in the array is the key of the property.
These are known to be data descriptors with a value field, writable field set to true, configurable field set to true, enumerable field set to true.
Since we know the properties of the property descriptors (and they are all the same) we can omit it and just store only the value field and construct the data property descriptor on demand.
Sparse Storage
This storage is used as a backup if the element keys are not continuous or the property descriptors
are not data descriptors with with a value field, writable field set to true, configurable field set to true, enumerable field set to true.
This method uses more space, since we also have to store the property descriptors, not just the value. It is also slower because we need to do a hash lookup.
Variants
DenseI32(ThinVec<i32>)
Dense i32 storage.
DenseF64(ThinVec<f64>)
Dense f64 storage.
DenseElement(ThinVec<JsValue>)
Dense JsValue storage.
Sparse(Box<HashMap<u32, PropertyDescriptor, FxBuildHasher>>)
Sparse JsValue storage.