Trait ReadChar
Source pub trait ReadChar {
// Required method
fn next_char(&mut self) -> Result<Option<u32>, Error>;
}
This trait is used to abstract over the different types of input readers.
Retrieves the next unicode code point. Returns None if the end of the input is reached.
Errors
Returns an error if the next input in the input is not a valid unicode code point.