pub struct StaticJsStrings;Expand description
List of commonly used strings in Javascript code.
Any strings defined here are used as a static JsString instead of allocating on the heap.
Implementations
Sourceimpl StaticJsStrings
impl StaticJsStrings
Sourcepub const EMPTY_STRING: JsString
pub const EMPTY_STRING: JsString
Gets the static JsString for "".
Sourcepub const SYMBOL_ASYNC_ITERATOR: JsString
pub const SYMBOL_ASYNC_ITERATOR: JsString
Gets the static JsString for "Symbol.asyncIterator".
Sourcepub const SYMBOL_HAS_INSTANCE: JsString
pub const SYMBOL_HAS_INSTANCE: JsString
Gets the static JsString for "Symbol.hasInstance".
Sourcepub const SYMBOL_IS_CONCAT_SPREADABLE: JsString
pub const SYMBOL_IS_CONCAT_SPREADABLE: JsString
Gets the static JsString for "Symbol.isConcatSpreadable".
Sourcepub const SYMBOL_ITERATOR: JsString
pub const SYMBOL_ITERATOR: JsString
Gets the static JsString for "Symbol.iterator".
Sourcepub const SYMBOL_MATCH: JsString
pub const SYMBOL_MATCH: JsString
Gets the static JsString for "Symbol.match".
Sourcepub const SYMBOL_MATCH_ALL: JsString
pub const SYMBOL_MATCH_ALL: JsString
Gets the static JsString for "Symbol.matchAll".
Sourcepub const SYMBOL_REPLACE: JsString
pub const SYMBOL_REPLACE: JsString
Gets the static JsString for "Symbol.replace".
Sourcepub const SYMBOL_SEARCH: JsString
pub const SYMBOL_SEARCH: JsString
Gets the static JsString for "Symbol.search".
Sourcepub const SYMBOL_SPECIES: JsString
pub const SYMBOL_SPECIES: JsString
Gets the static JsString for "Symbol.species".
Sourcepub const SYMBOL_SPLIT: JsString
pub const SYMBOL_SPLIT: JsString
Gets the static JsString for "Symbol.split".
Sourcepub const SYMBOL_TO_PRIMITIVE: JsString
pub const SYMBOL_TO_PRIMITIVE: JsString
Gets the static JsString for "Symbol.toPrimitive".
Sourcepub const SYMBOL_TO_STRING_TAG: JsString
pub const SYMBOL_TO_STRING_TAG: JsString
Gets the static JsString for "Symbol.toStringTag".
Sourcepub const SYMBOL_UNSCOPABLES: JsString
pub const SYMBOL_UNSCOPABLES: JsString
Gets the static JsString for "Symbol.unscopables".
Sourcepub const FN_SYMBOL_ASYNC_ITERATOR: JsString
pub const FN_SYMBOL_ASYNC_ITERATOR: JsString
Gets the static JsString for "[Symbol.asyncIterator]".
Sourcepub const FN_SYMBOL_HAS_INSTANCE: JsString
pub const FN_SYMBOL_HAS_INSTANCE: JsString
Gets the static JsString for "[Symbol.hasInstance]".
Sourcepub const FN_SYMBOL_IS_CONCAT_SPREADABLE: JsString
pub const FN_SYMBOL_IS_CONCAT_SPREADABLE: JsString
Gets the static JsString for "[Symbol.isConcatSpreadable]".
Sourcepub const FN_SYMBOL_ITERATOR: JsString
pub const FN_SYMBOL_ITERATOR: JsString
Gets the static JsString for "[Symbol.iterator]".
Sourcepub const FN_SYMBOL_MATCH: JsString
pub const FN_SYMBOL_MATCH: JsString
Gets the static JsString for "[Symbol.match]".
Sourcepub const FN_SYMBOL_MATCH_ALL: JsString
pub const FN_SYMBOL_MATCH_ALL: JsString
Gets the static JsString for "[Symbol.matchAll]".
Sourcepub const FN_SYMBOL_REPLACE: JsString
pub const FN_SYMBOL_REPLACE: JsString
Gets the static JsString for "[Symbol.replace]".
Sourcepub const FN_SYMBOL_SEARCH: JsString
pub const FN_SYMBOL_SEARCH: JsString
Gets the static JsString for "[Symbol.search]".
Sourcepub const FN_SYMBOL_SPECIES: JsString
pub const FN_SYMBOL_SPECIES: JsString
Gets the static JsString for "[Symbol.species]".
Sourcepub const FN_SYMBOL_SPLIT: JsString
pub const FN_SYMBOL_SPLIT: JsString
Gets the static JsString for "[Symbol.split]".
Sourcepub const FN_SYMBOL_TO_PRIMITIVE: JsString
pub const FN_SYMBOL_TO_PRIMITIVE: JsString
Gets the static JsString for "[Symbol.toPrimitive]".
Sourcepub const FN_SYMBOL_TO_STRING_TAG: JsString
pub const FN_SYMBOL_TO_STRING_TAG: JsString
Gets the static JsString for "[Symbol.toStringTag]".
Sourcepub const FN_SYMBOL_UNSCOPABLES: JsString
pub const FN_SYMBOL_UNSCOPABLES: JsString
Gets the static JsString for "[Symbol.unscopables]".
Sourcepub const ARRAY_BUFFER: JsString
pub const ARRAY_BUFFER: JsString
Gets the static JsString for "ArrayBuffer".
Sourcepub const SHARED_ARRAY_BUFFER: JsString
pub const SHARED_ARRAY_BUFFER: JsString
Gets the static JsString for "SharedArrayBuffer".
Sourcepub const ASYNC_FUNCTION: JsString
pub const ASYNC_FUNCTION: JsString
Gets the static JsString for "AsyncFunction".
Sourcepub const ASYNC_GENERATOR: JsString
pub const ASYNC_GENERATOR: JsString
Gets the static JsString for "AsyncGenerator".
Sourcepub const ASYNC_GENERATOR_FUNCTION: JsString
pub const ASYNC_GENERATOR_FUNCTION: JsString
Gets the static JsString for "AsyncGeneratorFunction".
Sourcepub const AGGREGATE_ERROR: JsString
pub const AGGREGATE_ERROR: JsString
Gets the static JsString for "AggregateError".
Sourcepub const EVAL_ERROR: JsString
pub const EVAL_ERROR: JsString
Gets the static JsString for "EvalError".
Sourcepub const RANGE_ERROR: JsString
pub const RANGE_ERROR: JsString
Gets the static JsString for "RangeError".
Sourcepub const REFERENCE_ERROR: JsString
pub const REFERENCE_ERROR: JsString
Gets the static JsString for "ReferenceError".
Sourcepub const SYNTAX_ERROR: JsString
pub const SYNTAX_ERROR: JsString
Gets the static JsString for "SyntaxError".
Sourcepub const TYPE_ERROR: JsString
pub const TYPE_ERROR: JsString
Gets the static JsString for "TypeError".
Sourcepub const GENERATOR_FUNCTION: JsString
pub const GENERATOR_FUNCTION: JsString
Gets the static JsString for "GeneratorFunction".
Sourcepub const LIST_FORMAT: JsString
pub const LIST_FORMAT: JsString
Gets the static JsString for "ListFormat".
Sourcepub const PLURAL_RULES: JsString
pub const PLURAL_RULES: JsString
Gets the static JsString for "PluralRules".
Sourcepub const DATE_TIME_FORMAT: JsString
pub const DATE_TIME_FORMAT: JsString
Gets the static JsString for "DateTimeFormat".
Sourcepub const NUMBER_FORMAT: JsString
pub const NUMBER_FORMAT: JsString
Gets the static JsString for "NumberFormat".
Sourcepub const PARSE_FLOAT: JsString
pub const PARSE_FLOAT: JsString
Gets the static JsString for "parseFloat".
Sourcepub const TYPED_ARRAY: JsString
pub const TYPED_ARRAY: JsString
Gets the static JsString for "TypedArray".
Sourcepub const INT8_ARRAY: JsString
pub const INT8_ARRAY: JsString
Gets the static JsString for "Int8Array".
Sourcepub const UINT8_ARRAY: JsString
pub const UINT8_ARRAY: JsString
Gets the static JsString for "Uint8Array".
Sourcepub const UINT8_CLAMPED_ARRAY: JsString
pub const UINT8_CLAMPED_ARRAY: JsString
Gets the static JsString for "Uint8ClampedArray".
Sourcepub const INT16_ARRAY: JsString
pub const INT16_ARRAY: JsString
Gets the static JsString for "Int16Array".
Sourcepub const UINT16_ARRAY: JsString
pub const UINT16_ARRAY: JsString
Gets the static JsString for "Uint16Array".
Sourcepub const INT32_ARRAY: JsString
pub const INT32_ARRAY: JsString
Gets the static JsString for "Int32Array".
Sourcepub const UINT32_ARRAY: JsString
pub const UINT32_ARRAY: JsString
Gets the static JsString for "Uint32Array".
Sourcepub const BIG_INT64_ARRAY: JsString
pub const BIG_INT64_ARRAY: JsString
Gets the static JsString for "BigInt64Array".
Sourcepub const BIG_UINT64_ARRAY: JsString
pub const BIG_UINT64_ARRAY: JsString
Gets the static JsString for "BigUint64Array".
Sourcepub const FLOAT16_ARRAY: JsString
pub const FLOAT16_ARRAY: JsString
Gets the static JsString for "Float16Array".
Sourcepub const FLOAT32_ARRAY: JsString
pub const FLOAT32_ARRAY: JsString
Gets the static JsString for "Float32Array".
Sourcepub const FLOAT64_ARRAY: JsString
pub const FLOAT64_ARRAY: JsString
Gets the static JsString for "Float64Array".
Sourcepub const ENCODE_URI: JsString
pub const ENCODE_URI: JsString
Gets the static JsString for "encodeURI".
Sourcepub const ENCODE_URI_COMPONENT: JsString
pub const ENCODE_URI_COMPONENT: JsString
Gets the static JsString for "encodeURIComponent".
Sourcepub const DECODE_URI: JsString
pub const DECODE_URI: JsString
Gets the static JsString for "decodeURI".
Sourcepub const DECODE_URI_COMPONENT: JsString
pub const DECODE_URI_COMPONENT: JsString
Gets the static JsString for "decodeURIComponent".
Sourcepub const INSTANT_TAG: JsString
pub const INSTANT_TAG: JsString
Gets the static JsString for "Temporal.Instant".
Sourcepub const DURATION_TAG: JsString
pub const DURATION_TAG: JsString
Gets the static JsString for "Temporal.Duration".
Sourcepub const PLAIN_DATE_TAG: JsString
pub const PLAIN_DATE_TAG: JsString
Gets the static JsString for "Temporal.PlainDate".
Sourcepub const PLAIN_DATETIME_TAG: JsString
pub const PLAIN_DATETIME_TAG: JsString
Gets the static JsString for "Temporal.PlainDateTime".
Sourcepub const PLAIN_TIME_TAG: JsString
pub const PLAIN_TIME_TAG: JsString
Gets the static JsString for "Temporal.PlainTime".
Sourcepub const PLAIN_YM_TAG: JsString
pub const PLAIN_YM_TAG: JsString
Gets the static JsString for "Temporal.PlainYearMonth".
Sourcepub const PLAIN_MD_TAG: JsString
pub const PLAIN_MD_TAG: JsString
Gets the static JsString for "Temporal.PlainMonthDay".
Sourcepub const ZONED_DT_TAG: JsString
pub const ZONED_DT_TAG: JsString
Gets the static JsString for "Temporal.ZonedDateTime".
Sourcepub const INSTANT_NAME: JsString
pub const INSTANT_NAME: JsString
Gets the static JsString for "Instant".
Sourcepub const DURATION_NAME: JsString
pub const DURATION_NAME: JsString
Gets the static JsString for "Duration".
Sourcepub const PLAIN_DATE_NAME: JsString
pub const PLAIN_DATE_NAME: JsString
Gets the static JsString for "PlainDate".
Sourcepub const PLAIN_DATETIME_NAME: JsString
pub const PLAIN_DATETIME_NAME: JsString
Gets the static JsString for "PlainDateTime".
Sourcepub const PLAIN_TIME_NAME: JsString
pub const PLAIN_TIME_NAME: JsString
Gets the static JsString for "PlainTime".
Sourcepub const PLAIN_YM_NAME: JsString
pub const PLAIN_YM_NAME: JsString
Gets the static JsString for "PlainYearMonth".
Sourcepub const PLAIN_MD_NAME: JsString
pub const PLAIN_MD_NAME: JsString
Gets the static JsString for "PlainMonthDay".
Sourcepub const ZONED_DT_NAME: JsString
pub const ZONED_DT_NAME: JsString
Gets the static JsString for "ZonedDateTime".
Sourcepub fn get_string(string: &JsStr<'_>) -> Option<JsString>
pub fn get_string(string: &JsStr<'_>) -> Option<JsString>
Gets the JsString corresponding to string, or None if the string
doesn’t exist inside the static array.