pub struct ConsoleState { /* private fields */ }Expand description
The current state of the console, passed to the logger backend. This should not be copied or cloned. References are only valid for the current logging call.
Implementations
Sourceimpl ConsoleState
impl ConsoleState